@@ -6,7 +6,7 @@ use warnings;
 
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.011_01';
+our $VERSION   = '0.001';
 
 use Moo;
 use Type::Tiny::Role;
@@ -14,13 +14,14 @@ use Types::URI -all;
 use Types::Standard qw(InstanceOf);
 use Attean;
 use Attean::RDF;
-use AtteanX::Plan::SPARQLBGP;
+use AtteanX::Store::SPARQL::Plan::BGP;
 use LWP::UserAgent;
 
 use Data::Dumper;
 use Carp;
 
 with 'Attean::API::TripleStore';
+with 'Attean::API::CostPlanner';
 with 'MooX::Log::Any';
 
 has 'endpoint_url' => (is => 'ro', isa => Uri, coerce => 1);
@@ -29,7 +30,7 @@ has 'ua' => (is => 'rw', isa => InstanceOf['LWP::UserAgent'], builder => '_build
 sub _build_ua {
 	my $self = shift;
 	my $ua = LWP::UserAgent->new;
-	$ua->default_headers->push_header( 'Accept' => 'application/sparql-results+json' ); #Attean->acceptable_parsers(handles => q[Attean::API::Result]));
+	$ua->default_headers->push_header( 'Accept' => Attean->acceptable_parsers(handles => q[Attean::API::Result]));
 	return $ua;
 }
 
@@ -52,6 +53,7 @@ sub get_sparql {
 	my $self = shift;
 	my $sparql = shift;
 	my $ua = shift || $self->ua;
+
 	my $url = $self->endpoint_url->clone;
 	my %query = $url->query_form;
 	$query{'query'} = $sparql;
@@ -62,7 +64,7 @@ sub get_sparql {
 		my $parsertype = Attean->get_parser( media_type => $response->content_type);
 		croak 'Could not parse response from '. $self->endpoint_url->as_string . ' which returned ' . $response->content_type unless defined($parsertype);
 		my $p = $parsertype->new;
-		return $p->parse_iter_from_bytes($response->content);
+		return $p->parse_iter_from_bytes($response->decoded_content);
 	} else {
 		$self->log->trace('Got an error, dumping the response: ' . Dumper($response));
 		croak 'Error making remote SPARQL call to endpoint ' . $self->endpoint_url->as_string . ' (' .$response->status_line. ')';
@@ -85,12 +87,18 @@ sub plans_for_algebra {
 															 graph => $active_graphs,
 															 distinct => 0));
 			  }
-		return AtteanX::Plan::SPARQLBGP->new(children => \@quads,
+		return AtteanX::Store::SPARQL::Plan::BGP->new(children => \@quads,
 																	 distinct => 0); # TODO: Fix
 	}
 	return;
 }
 
+sub cost_for_plan {
+	my $self = shift;
+	my $plan = shift;
+	return; #TODO for now
+}
+
 1;
 
 __END__
@@ -115,7 +123,7 @@ endpoints.
 
 This distribution also brings a corresponding
 L<AtteanX::Model::SPARQL>, which allows query plans to be made, and a
-L<AtteanX::Plan::SPARQLBGP> plan class, which contains a
+L<AtteanX::Store::SPARQL::Plan::BGP> plan class, which contains a
 rudimentary cost estimate that attempts to avoid sending Cartesian
 joins to remote endpoints if possible.
 
@@ -169,7 +177,7 @@ Kjetil Kjernsmo E<lt>kjetilk@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2015, 2016 by Kjetil Kjernsmo and Gregory
+This software is copyright (c) 2015 by Kjetil Kjernsmo and Gregory
 Todd Williams.
 
 This is free software; you can redistribute it and/or modify it under
